Module parser

Module parser 

The parser that do the real work

Structs

ParseError
A error type that indicate lines and columns when parsing goes wrong
Parser

Type Aliases

ParseResult
Alias for a parsing Result with the error type ParseError